==> kubernetes-model-apps-5.1.2-sources.jar: io/fabric8/kubernetes/api/model/apps/DaemonSetConditionBuilder.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class DaemonSetConditionBuilder extends DaemonSetConditionFluentImpl<DaemonSetConditionBuilder> implements VisitableBuilder<DaemonSetCondition,DaemonSetConditionBuilder> {

    DaemonSetConditionFluent<?> fluent;
    Boolean validationEnabled;

    public DaemonSetConditionBuilder() {
        this(true);
    }

    public DaemonSetConditionBuilder(Boolean validationEnabled) {
        this(new DaemonSetCondition(), validationEnabled);
    }

    public DaemonSetConditionBuilder(DaemonSetConditionFluent<?> fluent) {
        this(fluent, true);
    }

    public DaemonSetConditionBuilder(DaemonSetConditionFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new DaemonSetCondition(), validationEnabled);
    }

    public DaemonSetConditionBuilder(DaemonSetConditionFluent<?> fluent,DaemonSetCondition instance) {
        this(fluent, instance, true);
    }

    public DaemonSetConditionBuilder(DaemonSetConditionFluent<?> fluent,DaemonSetCondition instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
        fluent.withMessage(instance.getMessage()); 
        fluent.withReason(instance.getReason()); 
        fluent.withStatus(instance.getStatus()); 
        fluent.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }

    public DaemonSetConditionBuilder(DaemonSetCondition instance) {
        this(instance,true);
    }

    public DaemonSetConditionBuilder(DaemonSetCondition instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withLastTransitionTime(instance.getLastTransitionTime()); 
        this.withMessage(instance.getMessage()); 
        this.withReason(instance.getReason()); 
        this.withStatus(instance.getStatus()); 
        this.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }

    public DaemonSetCondition build() {
        DaemonSetCondition buildable = new DaemonSetCondition(fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        DaemonSetConditionBuilder that = (DaemonSetConditionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-apps-5.3.2-sources.jar: io/fabric8/kubernetes/api/model/apps/DaemonSetConditionBuilder.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class DaemonSetConditionBuilder extends DaemonSetConditionFluentImpl<DaemonSetConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<DaemonSetCondition,DaemonSetConditionBuilder> {

    DaemonSetConditionFluent<?> fluent;
    Boolean validationEnabled;

    public DaemonSetConditionBuilder() {
        this(true);
    }

    public DaemonSetConditionBuilder(Boolean validationEnabled) {
        this(new DaemonSetCondition(), validationEnabled);
    }

    public DaemonSetConditionBuilder(DaemonSetConditionFluent<?> fluent) {
        this(fluent, true);
    }

    public DaemonSetConditionBuilder(DaemonSetConditionFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new DaemonSetCondition(), validationEnabled);
    }

    public DaemonSetConditionBuilder(DaemonSetConditionFluent<?> fluent,DaemonSetCondition instance) {
        this(fluent, instance, true);
    }

    public DaemonSetConditionBuilder(DaemonSetConditionFluent<?> fluent,DaemonSetCondition instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
        fluent.withMessage(instance.getMessage()); 
        fluent.withReason(instance.getReason()); 
        fluent.withStatus(instance.getStatus()); 
        fluent.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }

    public DaemonSetConditionBuilder(DaemonSetCondition instance) {
        this(instance,true);
    }

    public DaemonSetConditionBuilder(DaemonSetCondition instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withLastTransitionTime(instance.getLastTransitionTime()); 
        this.withMessage(instance.getMessage()); 
        this.withReason(instance.getReason()); 
        this.withStatus(instance.getStatus()); 
        this.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }

    public DaemonSetCondition build() {
        DaemonSetCondition buildable = new DaemonSetCondition(fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        DaemonSetConditionBuilder that = (DaemonSetConditionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
